@@ -32,6 +32,7 @@ describe 'tripleo::profile::base::nova::compute' do
         is_expected.to_not contain_class('nova::vendordata')
         is_expected.to_not contain_class('nova::key_manager')
         is_expected.to_not contain_class('nova::key_manager::barbican')
+        is_expected.to_not contain_class('nova::policy')
         is_expected.to_not contain_class('nova::compute')
         is_expected.to_not contain_class('nova::network::neutron')
       }
@@ -63,6 +64,7 @@ eos
           is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::key_manager')
           is_expected.to contain_class('nova::key_manager::barbican')
+          is_expected.to contain_class('nova::policy')
           is_expected.to contain_class('nova::compute')
           is_expected.to contain_class('nova::network::neutron')
           is_expected.to_not contain_package('nfs-utils')
@@ -79,6 +81,7 @@ eos
           is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::key_manager')
           is_expected.to contain_class('nova::key_manager::barbican')
+          is_expected.to contain_class('nova::policy')
           is_expected.to contain_class('nova::compute')
           is_expected.to contain_class('nova::network::neutron')
           is_expected.to contain_package('nfs-utils')
@@ -95,6 +98,7 @@ eos
           is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::key_manager')
           is_expected.to contain_class('nova::key_manager::barbican')
+          is_expected.to contain_class('nova::policy')
           is_expected.to contain_class('nova::compute')
           is_expected.to contain_class('nova::network::neutron')
           is_expected.to contain_package('nfs-utils')
@@ -107,7 +111,7 @@ eos
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
-        facts.merge({ :hostname => 'node.example.com' })
+        facts.merge(OSDefaults.get_facts({ :hostname => 'node.example.com' }))
       end
 
       it_behaves_like 'tripleo::profile::base::nova::compute'
